==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/NamedContextBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedContextBuilder extends io.fabric8.kubernetes.api.model.NamedContextFluentImpl<io.fabric8.kubernetes.api.model.NamedContextBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.NamedContext,io.fabric8.kubernetes.api.model.NamedContextBuilder>{
  public NamedContextBuilder() {
    this(false);
  }
  public NamedContextBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedContext(), validationEnabled);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedContext(), validationEnabled);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,io.fabric8.kubernetes.api.model.NamedContext instance) {
    this(fluent, instance, false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,io.fabric8.kubernetes.api.model.NamedContext instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContext(instance.getContext()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContext instance) {
    this(instance,false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContext instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContext(instance.getContext()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.NamedContext build() {
    NamedContext buildable = new NamedContext(fluent.getContext(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedContextBuilder that = (NamedContextBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/NamedContextBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedContextBuilder extends io.fabric8.kubernetes.api.model.NamedContextFluentImpl<io.fabric8.kubernetes.api.model.NamedContextBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.NamedContext,io.fabric8.kubernetes.api.model.NamedContextBuilder>{
  public NamedContextBuilder() {
    this(false);
  }
  public NamedContextBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedContext(), validationEnabled);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedContext(), validationEnabled);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,io.fabric8.kubernetes.api.model.NamedContext instance) {
    this(fluent, instance, false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent,io.fabric8.kubernetes.api.model.NamedContext instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContext(instance.getContext()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContext instance) {
    this(instance,false);
  }
  public NamedContextBuilder(io.fabric8.kubernetes.api.model.NamedContext instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContext(instance.getContext()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NamedContextFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.NamedContext build() {
    NamedContext buildable = new NamedContext(fluent.getContext(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedContextBuilder that = (NamedContextBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
